# sdgs-dashboard

[![sdgs-dashboard - PyPi](https://img.shields.io/pypi/v/sdgs-dashboard)](https://pypi.org/project/sdgs-dashboard/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/sdgs-dashboard)](https://pypi.org/project/sdgs-dashboard/)
[![Donate Saweria](https://img.shields.io/badge/Donasi-Saweria-blue)](https://saweria.co/hexatester)
[![LISENSI](https://img.shields.io/github/license/hexatester/sdgs-dashboard)](https://github.com/hexatester/sdgs-dashboard/blob/main/LICENSE)

Modul python untuk dashboard sdgs kemendesa.
